CausalityDioInterceptor class

A Dio Interceptor that records all HTTP requests, responses, and errors as causal events in the TrinityEventBus.

Usage

final dio = Dio();
dio.interceptors.add(CausalityDioInterceptor());

All recording is assert-guarded — zero overhead in release builds.

Constructors

CausalityDioInterceptor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(DioException err, ErrorInterceptorHandler handler) → void
Called when an exception was occurred during the request.
onRequest(RequestOptions options, RequestInterceptorHandler handler) → void
Called when the request is about to be sent.
onResponse(Response response, ResponseInterceptorHandler handler) → void
Called when the response is about to be resolved.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited