CausalChangeNotifier class

A ChangeNotifier that automatically tracks state mutations in the TrinityEventBus causal graph.

Extend this instead of ChangeNotifier to get automatic causality tracking.

Usage

class CartModel extends CausalChangeNotifier {
  final List<String> _items = [];
  List<String> get items => List.unmodifiable(_items);

  void addItem(String item) {
    _items.add(item);
    notifyListeners(); // Automatically emits a causal event
  }
}
Inheritance

Constructors

CausalChangeNotifier()

Properties

causalDescription String
Override to provide a custom description for the causal event. Defaults to runtimeType: state_changed.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited