parentEventId property
The parent event's ID, if this context was created inside an existing CausalityZone.run call. Forms the parent edge in the CausalGraph.
Implementation
final String? parentEventId;
The parent event's ID, if this context was created inside an existing CausalityZone.run call. Forms the parent edge in the CausalGraph.
final String? parentEventId;