lastEvent property
CausalEvent?
get
lastEvent
Returns the last event in the buffer, or null if empty.
Implementation
CausalEvent? get lastEvent => _buffer.isNotEmpty ? _buffer.last : null;
Returns the last event in the buffer, or null if empty.
CausalEvent? get lastEvent => _buffer.isNotEmpty ? _buffer.last : null;