SnapshotSerializer class abstract

Abstract serializer for custom app state.

Implement this to teach RecoverableApp how to save/restore your specific state channels (e.g. auth tokens, cart items, etc.).

Constructors

SnapshotSerializer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restore(Map<String, dynamic> data) → void
Restore the app's custom state from a previously serialized map.
serialize() Map<String, dynamic>
Serialize the app's custom state into a JSON-safe map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited