LayoutExplanation class

A human-readable explanation of why a layout decision happened.

Constructors

LayoutExplanation({required LayoutDecision decision, required String title, required String detail, List<ConstraintChainLink>? constraintChain, List<FixSuggestion> suggestions = const []})
const

Properties

constraintChain List<ConstraintChainLink>?
The constraint chain from the widget to its root, if available.
final
decision LayoutDecision
The layout decision being explained.
final
detail String
Detailed explanation of WHY this happened.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suggestions List<FixSuggestion>
Suggested fixes, if any.
final
title String
Human-readable title (one line summary).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited