FixCategory enum

Categories for fix suggestions.

Inheritance
Available extensions

Values

addWrapper → const FixCategory

Add a wrapping widget (Expanded, Flexible, etc.)

changeProperty → const FixCategory

Change a property on the existing widget

replaceWidget → const FixCategory

Replace the widget with a different one

addScrollable → const FixCategory

Add a scrollable ancestor

constrainDimensions → const FixCategory

Constrain dimensions explicitly

general → const FixCategory

General / uncategorized fix

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FixCategory>
A constant List of the values in this enum, in order of their declaration.