CausalProxyUpdate class
A ProxyProvider-compatible wrapper that tracks when the proxy rebuilds.
Usage
ProxyProvider<AuthService, CartService>(
update: (ctx, auth, prev) {
return CausalProxyUpdate.track(
'CartService',
() => CartService(auth),
);
},
)
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited