CausalityProviderObserver class
A ProviderObserver that records all Riverpod provider state changes
as causal events in the TrinityEventBus.
Usage
void main() {
runApp(
ProviderScope(
observers: [CausalityProviderObserver()],
child: const MyApp(),
),
);
}
Records:
- Provider additions (initialization)
- Provider updates (state changes)
- Provider disposals
- Provider errors
All recording is assert-guarded — zero overhead in release builds.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
didAddProvider(
ProviderBase< Object?> provider, Object? value, ProviderContainer container) → void -
A provider was initialized, and the value exposed is
value. -
didDisposeProvider(
ProviderBase< Object?> provider, ProviderContainer container) → void - A provider was disposed
-
didUpdateProvider(
ProviderBase< Object?> provider, Object? previousValue, Object? newValue, ProviderContainer container) → void - Called by providers when they emit a notification.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
providerDidFail(
ProviderBase< Object?> provider, Object error, StackTrace stackTrace, ProviderContainer container) → void - A provider emitted an error, be it by throwing during initialization or by having a Future/Stream emit an error
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited