ErrorClassifier class
Classifies errors into severity levels based on error type patterns.
Uses a rule-based system matching the error's runtimeType name:
- Fatal: assertion, null, range, state, type errors
- Degraded: format, codec, argument errors
- Recoverable: network-related, timeout errors
If no rule matches, defaults to ErrorSeverity.degraded.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
classify(
Object error) → ErrorSeverity - Classify an error into a ErrorSeverity level.