ErrorFingerprint class
A fingerprint uniquely identifying an error class.
Two error instances that have the same root cause (same error type and same top 3 stack frames) will share the same fingerprint, even if they occur at different times or with different field values.
Constructors
-
ErrorFingerprint({required String hash, required String errorType, required List<
String> topFrames}) -
const
- ErrorFingerprint.compute(Object error, StackTrace stackTrace)
-
Compute a fingerprint from an error and its stack trace.
factory
Properties
- errorType → String
-
The error type name used in the fingerprint.
final
- hash → String
-
The SHA-256 hash fingerprint string.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
topFrames
→ List<
String> -
The top stack frames used in the fingerprint.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override