FallbackScreen class
A collection of pre-built fallback UI components for crash recovery and degraded states.
These are built exclusively with core Material widgets and have no external dependencies. They are designed to be crash-proof — if these fail, the architecture has failed. A full-screen fallback for fatal crashes.
This is used by RecoverableApp when not providing a custom
recoveryScreenBuilder. Can also be used standalone.
FallbackScreen(
title: 'Something went wrong',
subtitle: 'The app encountered an unexpected error.',
onRestart: () => Navigator.of(context).pushReplacementNamed('/'),
onStartFresh: () {
SnapshotManager.instance.wipe();
Navigator.of(context).pushReplacementNamed('/');
},
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FallbackScreen
Constructors
- FallbackScreen({Key? key, String title = 'Something went wrong', String subtitle = 'An unexpected error occurred.', ErrorFingerprint? fingerprint, AppSnapshot? lastSnapshot, required VoidCallback onRestart, required VoidCallback onStartFresh, bool isInCrashLoop = false})
-
const
Properties
- fingerprint → ErrorFingerprint?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInCrashLoop → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lastSnapshot → AppSnapshot?
-
final
- onRestart → VoidCallback
-
final
- onStartFresh → VoidCallback
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String
-
final
- title → String
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited